Window

Struct Window 

pub struct Window { /* private fields */ }

Implementations

Source

impl Window

pub unsafe fn new(parent: *mut lv_obj_t) -> Result<NonNull<Self>>

Create a new window.

Arguments
  • Parent_object - The parent object of the window.
Returns
  • Result<Self> - The result of the operation.
Safety

This function is unsafe because it may dereference raw pointers (e.g. Parent_object).

pub fn get_identifier(&self) -> usize

pub fn peek_event(&self) -> Option<Event>

pub fn pop_event(&mut self) -> Option<Event>

pub fn as_object(&self) -> &lv_obj_t

pub fn as_object_mutable(&mut self) -> &mut lv_obj_t

pub fn get_icon(&self) -> (&str, Color)

pub fn set_icon(&mut self, icon_string: &str, icon_color: Color)

pub fn wake_up(&mut self)

pub fn register_waker(&mut self, waker: &Waker)

pub unsafe fn from_raw(window: *mut lv_obj_t) -> Option<NonNull<Self>>

Convert a raw pointer to a window object.

Returns
  • Window - The raw pointer to the window.
Safety

This function is unsafe because it may dereference raw pointers (e.g. Window).

pub fn yield_now(&mut self) -> impl Future<Output = ()> + '_

pub fn delete(&mut self)

Methods from Deref<Target = lv_obj_t>

pub fn layout_inv(&self) -> u16

pub fn set_layout_inv(&mut self, val: u16)

pub fn readjust_scroll_after_layout(&self) -> u16

pub fn set_readjust_scroll_after_layout(&mut self, val: u16)

pub fn scr_layout_inv(&self) -> u16

pub fn set_scr_layout_inv(&mut self, val: u16)

pub fn skip_trans(&self) -> u16

pub fn set_skip_trans(&mut self, val: u16)

pub fn style_cnt(&self) -> u16

pub fn set_style_cnt(&mut self, val: u16)

pub fn h_layout(&self) -> u16

pub fn set_h_layout(&mut self, val: u16)

pub fn w_layout(&self) -> u16

pub fn set_w_layout(&mut self, val: u16)

pub fn is_deleting(&self) -> u16

pub fn set_is_deleting(&mut self, val: u16)